@@ -1,7 +1,7 @@
 from __future__ import annotations
 from typing import List
-import malifpy_ffnn.layer as layer
 
+from .layer import Layer
 
 class FeedForwardNeuralNetwork:
     def __init__(self, totalLayers: int) -> None:
@@ -16,7 +16,7 @@ class FeedForwardNeuralNetwork:
             weight: List[float]
         ):
         self.layers.append(
-                layer.Layer(
+                Layer(
                     activation_function,
                     totalNeurons,
                     weight_dim,
