@@ -1,7 +1,7 @@
 from __future__ import annotations
 from typing import Callable, List
-import malifpy_ffnn.activation_function as act_fun
 
+from .activation_function import softMax
 
 class Layer:
     def __init__(
@@ -19,7 +19,7 @@ class Layer:
 
     def get_activation_function(self) -> Callable[..., float]:
         def act_func(f):
-            return act_fun.softMax(f, self.get_sum_of_weighted_sum())
+            return softMax(f, self.get_sum_of_weighted_sum())
         return act_func
 
     def get_sum_of_weighted_sum(self):
