@@ -1,7 +1,7 @@
 from __future__ import annotations
 from typing import Union
 
-import malifpy_ffnn.feed_forward_neural_network as ffnn
+from .feed_forward_neural_network import FeedForwardNeuralNetwork
 
 class FFNNModelFile:
     def __init__(self, model_file: str) -> None:
@@ -13,13 +13,13 @@ class FFNNModelFile:
         with open(self.model_file, "r") as model_file:
             model_txt: str = model_file.read()
             model_split = model_txt.split("\n\n")
-            self.ffnn = ffnn.FeedForwardNeuralNetwork(int(model_split[0]))
+            self.ffnn = FeedForwardNeuralNetwork(int(model_split[0]))
             for line in model_split[1:]:
                 arg_arr = line.splitlines()
                 act_func = arg_arr[0]
                 totalNeurons = int(arg_arr[1])
                 weight_dim = [int(dim) for dim in arg_arr[2].split()]
-                weight = [float(w) for w in arg_arr[2].split()]
+                weight = [float(w) for w in arg_arr[3].split()]
                 self.ffnn.add_layer(
                         act_func,
                         totalNeurons,
@@ -28,7 +28,7 @@ class FFNNModelFile:
                     )
         return self
 
-    def get_ffnn(self) -> ffnn.FeedForwardNeuralNetwork:
+    def get_ffnn(self) -> FeedForwardNeuralNetwork:
         return self.ffnn
 
 if __name__ == "__main__":
