@@ -1,5 +1,6 @@
 from __future__ import annotations
 from typing import List, Union
+from .synapse import Synapse
 
 class Neuron:
     def __init__(self) -> None:
@@ -26,7 +27,7 @@ class Neuron:
         """
         Menghubungkan Neuron argumen **KE** Neuron ini.
         """
-        new_synapse : Synapse = malifpy_ffnn.synapse.Synapse(neuron_arg, self)
+        new_synapse : Synapse = Synapse(neuron_arg, self)
         self.add_synapse_in(new_synapse)
         neuron_arg.add_synapse_out(new_synapse)
 
