@@ -1,4 +1,4 @@
-from .neuron import Neuron
+from __future__ import annotations
 
 class Synapse:
     def __init__(
